@@ -79,7 +79,7 @@ __verbose = None
 __DFU_INTERFACE = 0
 
 import inspect
-if 'length' in inspect.getargspec(usb.util.get_string).args:
+if 'length' in inspect.getfullargspec(usb.util.get_string).args:
     # PyUSB 1.0.0.b1 has the length argument
     def get_string(dev, index):
         return usb.util.get_string(dev, 255, index)
