@@ -100,7 +100,7 @@ class DruidUi:
             layout=self.layout,
             key_bindings=self.key_bindings,
             style=self.style,
-            mouse_support=True,
+            mouse_support=False,
             full_screen=True,
         )
 
@@ -149,11 +149,9 @@ class ReplCompleter(Completer):
         "bootloader": "Reboot into bootloader",
         "clear": "Clear the saved user script",
         "first": "Set First as the current script and reboot",
-        "help": "Show help",
         "identity": "Show crow's serial number",
         "kill": "Restart the Lua environment",
         "print": "Print the current user script",
-        "quit": "Quit druid",
         "reset": "Reboot crow",
         "run": "Send a file to crow and run it",
         "upload": "Send a file to crow, store and run it",
